@@ -22,8 +22,7 @@
 #'
 #' @examples
 #' \donttest{
-#' databases <- index_fqa_databases()
-#' # Note that the 2017 Chicago database has id_number 149
+#' databases <- index_fqa_databases() # The 2017 Chicago database has id_number 149
 #' chicago_2017_assessments <- index_fqa_assessments(149)
 #' }
 #'
@@ -31,27 +30,18 @@
 
 
 index_fqa_assessments <- function(database_id) {
-  out <- tryCatch(index_fqa_assessments_internal(database_id),
-                  warning = function(w) {
-                    warning(w)
-                    memoise::drop_cache(index_fqa_assessments_internal)({{ database_id }})
-                    return(invisible(NULL))
-                  },
-                  message = function(m) {
-                    message(m)
-                    memoise::drop_cache(index_fqa_assessments_internal)({{ database_id }})
-                    return(invisible(NULL))
-                  }
-  )
 
-  if (is.null(out)){
+  out <- index_fqa_assessments_internal(database_id)
+
+  if (nrow(out) == 0){
     memoise::drop_cache(index_fqa_assessments_internal)({{ database_id }})
+    return(invisible(out))
   }
 
   out
-
 }
 
 
 
 
+
