@@ -22,8 +22,7 @@
 #'
 #' @examples
 #' \donttest{
-#' databases <- index_fqa_databases()
-#' # Note that the 2017 Chicago database has id_number 149
+#' databases <- index_fqa_databases() # The 2017 Chicago database has id_number 149
 #' chicago_2017_transects <- index_fqa_transects(149)
 #' }
 #'
@@ -32,21 +31,11 @@
 
 index_fqa_transects <- function(database_id) {
 
-  out <- tryCatch(index_fqa_transects_internal(database_id),
-                  warning = function(w) {
-                    warning(w)
-                    memoise::drop_cache(index_fqa_transects_internal)({{ database_id }})
-                    return(invisible(NULL))
-                  },
-                  message = function(m) {
-                    message(m)
-                    memoise::drop_cache(index_fqa_transects_internal)({{ database_id }})
-                    return(invisible(NULL))
-                  }
-  )
+  out <- index_fqa_transects_internal(database_id)
 
-  if (is.null(out)){
+  if (nrow(out) == 0){
     memoise::drop_cache(index_fqa_transects_internal)({{ database_id }})
+    return(invisible(out))
   }
 
   out
